macro_rules! runtime_wasm_functions {
($( $symbol:expr => $export:literal ( $( $param:ident ),* ) -> $result:tt ; )* ) => { ... };
}Expand description
Build a static runtime descriptor slice with minimal duplication.
macro_rules! runtime_wasm_functions {
($( $symbol:expr => $export:literal ( $( $param:ident ),* ) -> $result:tt ; )* ) => { ... };
}Build a static runtime descriptor slice with minimal duplication.